function [DN] = calc_DN_map(U, J, elec_area, elec_position_angle, elec_position_radius)
%calculates the Dirichlet-to-Neumann-Map based on:
% U <number of electrodes>*<number of linear independend current patterns>:
% measured voltages

% J <number of electrodes>*<number of linear independend current patterns>:
% stimulation current pattern

%optional arguments:
% elec_position_angle <number of electrodes>:
% angle of the electrode measured from the center and the x-axis

% elec_position_radius <number of electrodes>:
% distance of the electrode from center to electrode


%if no electrode positions are given, the correction term is not needed as
%we just assume a circular domain
if nargin > 3
    
    %It can happen that the angles are not ranging from 0 to 2pi, but take
    %negative calues upwards of pi
    if elec_position_angle(end) < 0
        elec_position_angle_last = elec_position_angle(end);
    else
        elec_position_angle_last = 2*pi - elec_position_angle(end);
    end
    
    elec_position_angle(elec_position_angle < 0 & ...
        abs(elec_position_angle) > 1e-10) = ...
        2*pi + elec_position_angle(elec_position_angle <0 &  ...
        abs(elec_position_angle) > 1e-10);
    
    %append the last element at the beginning for the correction term
    elec_position_angle = [elec_position_angle_last; ...
        elec_position_angle];
    elec_position_radius = [elec_position_radius(end); ...
        elec_position_radius];
    
    %calcualte the differences between angles and radii
    elec_position_angle_del = diff(elec_position_angle);
    elec_position_radius_del = diff(elec_position_radius);
    
    %calculate the correctionfactor
    arclength_differential = sqrt(elec_position_radius.^2 + ...
        (elec_position_radius_del./elec_position_angle_del).^2).*elec_position_angle_del;
    
    % calculates the ND map, full(J) is there to be compatible to EIDORS
    NtoD = (1/elec_area)*(arclength_differential.*full(J))'*U;
    
else
    
    % calculates the ND map, full(J) is there to be compatible to EIDORS
    NtoD = (1/elec_area)*(full(J)'*U);
    
end
%invert the ND map to get the DN map
DN = inv(NtoD);
end